@@ -1,15 +1,15 @@
 # Copyright (c) 2004, 2005 Anders Ard
 
-## $Id: Config.pm 288 2008-10-30 11:52:48Z it-aar $
+## $Id: Config.pm,v 1.10 2006/12/13 15:06:27 anders Exp $
 # 
 # See the file LICENCE included in the distribution.
 
 package Combine::Config;
 
 use strict;
-use Config::General qw(SaveConfigString);
+use Config::General;
 
-our $VERSION = '3.11';
+our $VERSION = '3.5';
 our %serverbypreferred = ();
 our %serverbyalias     = ();
 our @allow = ();
