@@ -1,5 +1,5 @@
 # Copyright (c) 2004, 2005 Anders Ard
-## $Id: DataBase.pm 286 2008-10-13 09:13:26Z it-aar $
+## $Id: DataBase.pm,v 1.5 2007/02/21 10:34:57 anders Exp $
 
 # 
 # See the file LICENCE included in the distribution.
@@ -9,7 +9,6 @@ package Combine::DataBase;
 use strict;
 use Combine::MySQLhdb;
 use Digest::MD5;
-use Encode qw(encode_utf8);
 
 sub new { 
     my ($class, $xwi, $sv, $loghandle) = @_;
@@ -31,10 +30,10 @@ sub delete {
     return undef unless ref $xwi;
     
     my $urlid = $xwi->urlid;
-    my ($recordid, $md5) = $self->{databasehandle}->selectrow_array(
-              qq{SELECT recordid,md5 FROM recordurl WHERE urlid=$urlid;}); #Only one
+    my ($recordid) = $self->{databasehandle}->selectrow_array(
+              qq{SELECT recordid FROM recordurl WHERE urlid=$urlid;}); #Only one
     return if !defined($recordid);
-    $self->{'loghandle'}->say("DataBase::delete $urlid, $recordid, $md5;");
+    $self->{'loghandle'}->say("DataBase::delete $urlid, $recordid;");
 #LOCK recordurl - needed?
     $self->{databasehandle}->prepare(qq{LOCK TABLES recordurl WRITE;})->execute();
     #delete URL from recordurl
@@ -43,7 +42,7 @@ sub delete {
               qq{SELECT recordid FROM recordurl WHERE recordid=$recordid LIMIT 1;});
 #UNLOCK recordurl - needed?
     $self->{databasehandle}->prepare(qq{UNLOCK TABLES;})->execute();
-    if ( !defined($ant) || ($ant == 0) ) { Combine::MySQLhdb::DeleteKey($recordid,$md5); } #Should handle del's of non-existing recs
+    if ( !defined($ant) || ($ant == 0) ) { Combine::MySQLhdb::DeleteKey($recordid); } #Should handle del's of non-existing recs
 
     $xwi->nofollow("true"); #?? check??
 }
@@ -59,9 +58,9 @@ sub insert {
     my $md5D = new Digest::MD5;
     $md5D->reset;
     if ( length($xwi->text) > 0 ) {
-	my $text = ${$xwi->text};
+	my $text = $$xwi->text;
 	$text =~ s/[\s\n\r]+//g;
-	$md5D->add(encode_utf8($text)); #use only visible text without whitespace
+	$md5D->add($text); #use only visible text without whitespace
     } else {
 	$md5D->add($xwi->url);
 	$md5D->add($xwi->type());
@@ -125,7 +124,7 @@ sub insert {
 	          qq{SELECT recordid FROM recordurl WHERE recordid=$oldrecordid LIMIT 1;}); #Outside LOCK?
 	if ( ! defined($ant) ) { $ant = 0; }
 	$self->{'loghandle'}->say("DataBase::DelURL case 2: $oldrecordid; $ant;; $existrecordid; $existurlid; $oldmd5;");
-	if ( $ant == 0 ) { Combine::MySQLhdb::DeleteKey($oldrecordid, $oldmd5); }
+	if ( $ant == 0 ) { Combine::MySQLhdb::DeleteKey($oldrecordid); }
 
 #CASE 3
     } elsif ( $existrecordid && ! $existurlid ) {
@@ -153,7 +152,7 @@ sub insert {
               qq{SELECT recordid FROM recordurl WHERE recordid=$oldrecordid LIMIT 1;});
 	if ( ! defined($ant) ) { $ant = 0; }
 	$self->{'loghandle'}->say("DataBase::DelURL $oldrecordid; $ant;");
-	if ( $ant == 0 ) { Combine::MySQLhdb::DeleteKey($oldrecordid, $oldmd5); }
+	if ( $ant == 0 ) { Combine::MySQLhdb::DeleteKey($oldrecordid); }
 	my ($recordid) = $self->{databasehandle}->selectrow_array(
               qq{SELECT recordid FROM recordurl WHERE urlid=$urlid;});
 	$xwi->recordid($recordid);
