@@ -52,7 +52,7 @@ sub Write {
     my $title = $xwi->title;
 #checkedDate is inserted/updated in DataBase.pm and harvpars.pl
     my $modifiedDate = $xwi->modifiedDate;
-    if ( ! $modifiedDate) { $modifiedDate = $xwi->checkedDate; }
+#    if ( ! $modifiedDate) { $modifiedDate = $checkedDate; }
     my $expiryDate = $xwi->expiryDate;
 #    if ($expiryDate) { $expiryDate = str2time($expiryDate) ; }
 #    else { $expiryDate = 'NULL'; }
@@ -91,7 +91,7 @@ sub Write {
       else {
         $ip = $this ;
       }
-    } else { my $t=''; $xwi->text(\$t); } #make sure xwi->text is defined
+    }
 #??    if (length($ip)>250000) {$ip = substr($ip, 0, 250000);}
 
     $sv->prepare("REPLACE INTO hdb VALUES (?, ?, ?, FROM_UNIXTIME( ? ), FROM_UNIXTIME( ? ), ?, ?, ?, ?, ?, ?, COMPRESS(?))")->execute(
@@ -200,9 +200,6 @@ sub Write {
       require Combine::Zebra;
       Combine::Zebra::update($zh,$xwi);
     }
-    if (Combine::Config::Get('MySQLfulltext')) {
-      $sv->prepare("REPLACE INTO search VALUES (?, ?)")->execute($recordid, Encode::encode('utf8',$title .' '. $ip));
-    }
 }
 
 sub Delete { #Used??
@@ -211,31 +208,22 @@ sub Delete { #Used??
 
     my $recordid = $xwi->recordid; 
 #print "MySQLhdb::DeleteMD5 $recordid\n";
-    DeleteKey($recordid, $xwi->md5);
+    DeleteKey($recordid);
 }
 
 sub DeleteKey {
-    my ($key, $md5) = @_;
+    my ($key) = @_;
     if (!defined($sv)) { Open(); } #Init $sv CHANGE?
 #OAI
      if ($doOAI) {
 #     $sv->prepare("REPLACE INTO oai SET status='deleted', recordid=?, md5=?")->execute($key,$md5);
-##FEL recurdurl updaterad i Database.pm FIX!
        $sv->prepare("REPLACE INTO oai SELECT recordid,md5,NOW(),'deleted' FROM recordurl WHERE recordid=?")->execute($key);
      }
 #OAI
 
-#Zebra
-    if (my $zh = Combine::Config::Get('ZebraHost')) {
-      require Combine::Zebra;
-#Not needed: if ($md5 eq '') { ($md5)=$sv->selectrow_array('SELECT md5 FROM recordurl WHERE recordid=$key'); }
-      Combine::Zebra::delete($zh, $md5, $key);
-    }
-
 #print "MySQLhdb::DeleteKey $key\n";
     my $res = $sv->do(qq{DELETE FROM hdb WHERE recordid=$key;});
     $res = $sv->do(qq{DELETE FROM html WHERE recordid=$key;});
-    $res = $sv->do(qq{DELETE FROM search WHERE recordid=$key;});
     $res = $sv->do(qq{DELETE FROM meta WHERE recordid=$key;});
     $res = $sv->do(qq{DELETE FROM analys WHERE recordid=$key});
     $res = $sv->do(qq{DELETE FROM links WHERE recordid=$key;});
@@ -274,9 +262,6 @@ sub Get {
     my $html = Encode::decode('utf8',$html1);
     $xwi->content(\$html);
 
-    my ($urlpath) = $sv->selectrow_array(qq{SELECT path FROM urls,recordurl WHERE recordid='$key' AND recordurl.urlid=urls.urlid;});
-    $xwi->urlpath($urlpath);
-
     my ($url,$anchor,$lty,$name,$value,$heading);
 #links
     my $sth = $sv->prepare(qq{SELECT urlid,netlocid,anchor,linktype from links WHERE recordid='$key';});
