@@ -1,4 +1,4 @@
-# LaTeX2HTML 2002-2-1 (1.71)
+# LaTeX2HTML 2002-2-1 (1.70)
 # Associate labels original text with physical files.
 
 
@@ -38,10 +38,6 @@ $key = q/load/;
 $external_labels{$key} = "$URL/" . q|node4.html|; 
 $noresave{$key} = "$nosave";
 
-$key = q/analysis/;
-$external_labels{$key} = "$URL/" . q|node6.html|; 
-$noresave{$key} = "$nosave";
-
 $key = q/Actions_for_controlling_scheduling_of_URLs/;
 $external_labels{$key} = "$URL/" . q|node16.html|; 
 $noresave{$key} = "$nosave";
@@ -242,10 +238,6 @@ $key = q/httpProxy/;
 $external_labels{$key} = "$URL/" . q|node13.html|; 
 $noresave{$key} = "$nosave";
 
-$key = q/relTextPlugin/;
-$external_labels{$key} = "$URL/" . q|node13.html|; 
-$noresave{$key} = "$nosave";
-
 $key = q/doCheckRecord/;
 $external_labels{$key} = "$URL/" . q|node13.html|; 
 $noresave{$key} = "$nosave";
@@ -394,10 +386,6 @@ $key = q/gory/;
 $external_labels{$key} = "$URL/" . q|node11.html|; 
 $noresave{$key} = "$nosave";
 
-$key = q/SVMmodel/;
-$external_labels{$key} = "$URL/" . q|node13.html|; 
-$noresave{$key} = "$nosave";
-
 $key = q/cite_Yang_99/;
 $external_labels{$key} = "$URL/" . q|node10.html|; 
 $noresave{$key} = "$nosave";
@@ -410,10 +398,6 @@ $key = q/_get/;
 $external_labels{$key} = "$URL/" . q|node16.html|; 
 $noresave{$key} = "$nosave";
 
-$key = q/analysePlugin/;
-$external_labels{$key} = "$URL/" . q|node13.html|; 
-$noresave{$key} = "$nosave";
-
 $key = q/new_/;
 $external_labels{$key} = "$URL/" . q|node16.html|; 
 $noresave{$key} = "$nosave";
@@ -422,14 +406,14 @@ $key = q/gettingstarted/;
 $external_labels{$key} = "$URL/" . q|node4.html|; 
 $noresave{$key} = "$nosave";
 
-$key = q/LICENSE/;
-$external_labels{$key} = "$URL/" . q|node16.html|; 
-$noresave{$key} = "$nosave";
-
 $key = q/exclude/;
 $external_labels{$key} = "$URL/" . q|node13.html|; 
 $noresave{$key} = "$nosave";
 
+$key = q/LICENSE/;
+$external_labels{$key} = "$URL/" . q|node16.html|; 
+$noresave{$key} = "$nosave";
+
 $key = q/cite_GolubChall/;
 $external_labels{$key} = "$URL/" . q|node10.html|; 
 $noresave{$key} = "$nosave";
@@ -482,10 +466,6 @@ $key = q/UAtimeout/;
 $external_labels{$key} = "$URL/" . q|node13.html|; 
 $noresave{$key} = "$nosave";
 
-$key = q/MySQLfulltext/;
-$external_labels{$key} = "$URL/" . q|node13.html|; 
-$noresave{$key} = "$nosave";
-
 $key = q/baseConfigDir/;
 $external_labels{$key} = "$URL/" . q|node13.html|; 
 $noresave{$key} = "$nosave";
@@ -506,14 +486,14 @@ $key = q/sessionids/;
 $external_labels{$key} = "$URL/" . q|node13.html|; 
 $noresave{$key} = "$nosave";
 
-$key = q/_reset_/;
-$external_labels{$key} = "$URL/" . q|node16.html|; 
-$noresave{$key} = "$nosave";
-
 $key = q/cite_ardo99:_online99/;
 $external_labels{$key} = "$URL/" . q|node10.html|; 
 $noresave{$key} = "$nosave";
 
+$key = q/_reset_/;
+$external_labels{$key} = "$URL/" . q|node16.html|; 
+$noresave{$key} = "$nosave";
+
 $key = q/termlist/;
 $external_labels{$key} = "$URL/" . q|node6.html|; 
 $noresave{$key} = "$nosave";
@@ -526,11 +506,11 @@ $key = q/InstTest/;
 $external_labels{$key} = "$URL/" . q|node16.html|; 
 $noresave{$key} = "$nosave";
 
-$key = q/Actions_loading_or_recycling_URLs_for_crawling/;
+$key = q/topic_reset_topic_rewind_topic_add_topic_get_/;
 $external_labels{$key} = "$URL/" . q|node16.html|; 
 $noresave{$key} = "$nosave";
 
-$key = q/topic_reset_topic_rewind_topic_add_topic_get_/;
+$key = q/Actions_loading_or_recycling_URLs_for_crawling/;
 $external_labels{$key} = "$URL/" . q|node16.html|; 
 $noresave{$key} = "$nosave";
 
@@ -550,14 +530,14 @@ $key = q/debian/;
 $external_labels{$key} = "$URL/" . q|node4.html|; 
 $noresave{$key} = "$nosave";
 
-$key = q/WaitIntervalHarvesterLockSuccess/;
-$external_labels{$key} = "$URL/" . q|node13.html|; 
-$noresave{$key} = "$nosave";
-
 $key = q/_rewind_/;
 $external_labels{$key} = "$URL/" . q|node16.html|; 
 $noresave{$key} = "$nosave";
 
+$key = q/WaitIntervalHarvesterLockSuccess/;
+$external_labels{$key} = "$URL/" . q|node13.html|; 
+$noresave{$key} = "$nosave";
+
 $key = q/cite_Svenonius_2000/;
 $external_labels{$key} = "$URL/" . q|node10.html|; 
 $noresave{$key} = "$nosave";
@@ -581,20 +561,20 @@ $noresave{$key} = "$nosave";
 1;
 
 
-# LaTeX2HTML 2002-2-1 (1.71)
+# LaTeX2HTML 2002-2-1 (1.70)
 # labels from external_latex_labels array.
 
 
 $key = q/maxUrlLength/;
-$external_latex_labels{$key} = q|9.1.15|; 
+$external_latex_labels{$key} = q|9.1.14|; 
 $noresave{$key} = "$nosave";
 
 $key = q/Actions_for_deleting_records/;
-$external_latex_labels{$key} = q|A.5.7|; 
+$external_latex_labels{$key} = q|A.5.6|; 
 $noresave{$key} = "$nosave";
 
 $key = q/WaitIntervalHarvesterLockNotFound/;
-$external_latex_labels{$key} = q|9.1.31|; 
+$external_latex_labels{$key} = q|9.1.27|; 
 $noresave{$key} = "$nosave";
 
 $key = q/appendix/;
@@ -602,11 +582,11 @@ $external_latex_labels{$key} = q|A|;
 $noresave{$key} = "$nosave";
 
 $key = q/WaitIntervalExpirationGuaranteed/;
-$external_latex_labels{$key} = q|9.1.30|; 
+$external_latex_labels{$key} = q|9.1.26|; 
 $noresave{$key} = "$nosave";
 
 $key = q/Password/;
-$external_latex_labels{$key} = q|9.1.20|; 
+$external_latex_labels{$key} = q|9.1.18|; 
 $noresave{$key} = "$nosave";
 
 $key = q/crawlspeed/;
@@ -626,7 +606,7 @@ $external_latex_labels{$key} = q|9.2.7|;
 $noresave{$key} = "$nosave";
 
 $key = q/Actions_for_sanity_controlls/;
-$external_latex_labels{$key} = q|A.5.7|; 
+$external_latex_labels{$key} = q|A.5.6|; 
 $noresave{$key} = "$nosave";
 
 $key = q/configuration/;
@@ -638,19 +618,19 @@ $external_latex_labels{$key} = q|2|;
 $noresave{$key} = "$nosave";
 
 $key = q/Loglev/;
-$external_latex_labels{$key} = q|9.1.14|; 
+$external_latex_labels{$key} = q|9.1.13|; 
 $noresave{$key} = "$nosave";
 
 $key = q/HarvesterMaxMissions/;
-$external_latex_labels{$key} = q|9.1.10|; 
+$external_latex_labels{$key} = q|9.1.9|; 
 $noresave{$key} = "$nosave";
 
 $key = q/url_remove_url_reset_url_rewind_url_add_url_get_/;
-$external_latex_labels{$key} = q|A.5.11|; 
+$external_latex_labels{$key} = q|A.5.15|; 
 $noresave{$key} = "$nosave";
 
 $key = q/doOAI/;
-$external_latex_labels{$key} = q|9.1.8|; 
+$external_latex_labels{$key} = q|9.1.7|; 
 $noresave{$key} = "$nosave";
 
 $key = q/extmods/;
@@ -658,15 +638,11 @@ $external_latex_labels{$key} = q|10.3|;
 $noresave{$key} = "$nosave";
 
 $key = q/Action_all/;
-$external_latex_labels{$key} = q|A.5.7|; 
-$noresave{$key} = "$nosave";
-
-$key = q/analysis/;
-$external_latex_labels{$key} = q|4.8|; 
+$external_latex_labels{$key} = q|A.5.6|; 
 $noresave{$key} = "$nosave";
 
 $key = q/Actions_for_controlling_scheduling_of_URLs/;
-$external_latex_labels{$key} = q|A.5.2|; 
+$external_latex_labels{$key} = q|A.5.1|; 
 $noresave{$key} = "$nosave";
 
 $key = q/comp/;
@@ -674,15 +650,15 @@ $external_latex_labels{$key} = q|7|;
 $noresave{$key} = "$nosave";
 
 $key = q/AutoRecycleLinks/;
-$external_latex_labels{$key} = q|9.1.2|; 
+$external_latex_labels{$key} = q|9.1.1|; 
 $noresave{$key} = "$nosave";
 
 $key = q/heading_reset_heading_rewind_heading_add_heading_get_/;
-$external_latex_labels{$key} = q|A.5.11|; 
+$external_latex_labels{$key} = q|A.5.15|; 
 $noresave{$key} = "$nosave";
 
 $key = q/WaitIntervalHarvesterLockUnavailable/;
-$external_latex_labels{$key} = q|9.1.35|; 
+$external_latex_labels{$key} = q|9.1.31|; 
 $noresave{$key} = "$nosave";
 
 $key = q/crawl/;
@@ -690,15 +666,15 @@ $external_latex_labels{$key} = q|3|;
 $noresave{$key} = "$nosave";
 
 $key = q/Actions_starting_killing_crawlers/;
-$external_latex_labels{$key} = q|A.5.2|; 
+$external_latex_labels{$key} = q|A.5.1|; 
 $noresave{$key} = "$nosave";
 
 $key = q/SummaryLength/;
-$external_latex_labels{$key} = q|9.1.24|; 
+$external_latex_labels{$key} = q|9.1.21|; 
 $noresave{$key} = "$nosave";
 
 $key = q/SdqRetries/;
-$external_latex_labels{$key} = q|9.1.23|; 
+$external_latex_labels{$key} = q|9.1.20|; 
 $noresave{$key} = "$nosave";
 
 $key = q/urlfilt/;
@@ -706,7 +682,7 @@ $external_latex_labels{$key} = q|4.3|;
 $noresave{$key} = "$nosave";
 
 $key = q/Actions_listing_statistics/;
-$external_latex_labels{$key} = q|A.5.7|; 
+$external_latex_labels{$key} = q|A.5.6|; 
 $noresave{$key} = "$nosave";
 
 $key = q/crawlstrategy/;
@@ -718,11 +694,11 @@ $external_latex_labels{$key} = q|1|;
 $noresave{$key} = "$nosave";
 
 $key = q/xmeta_reset_xmeta_rewind_xmeta_add_xmeta_get_/;
-$external_latex_labels{$key} = q|A.5.11|; 
+$external_latex_labels{$key} = q|A.5.15|; 
 $noresave{$key} = "$nosave";
 
 $key = q/METHODS/;
-$external_latex_labels{$key} = q|A.5.11|; 
+$external_latex_labels{$key} = q|A.5.15|; 
 $noresave{$key} = "$nosave";
 
 $key = q/slowcrawl/;
@@ -746,11 +722,11 @@ $external_latex_labels{$key} = q|2|;
 $noresave{$key} = "$nosave";
 
 $key = q/WaitIntervalRrdLockSuccess/;
-$external_latex_labels{$key} = q|9.1.39|; 
+$external_latex_labels{$key} = q|9.1.35|; 
 $noresave{$key} = "$nosave";
 
 $key = q/NAME/;
-$external_latex_labels{$key} = q|A.5.20|; 
+$external_latex_labels{$key} = q|A.5.16|; 
 $noresave{$key} = "$nosave";
 
 $key = q/faq/;
@@ -758,15 +734,15 @@ $external_latex_labels{$key} = q|8|;
 $noresave{$key} = "$nosave";
 
 $key = q/useTidy/;
-$external_latex_labels{$key} = q|9.1.29|; 
+$external_latex_labels{$key} = q|9.1.25|; 
 $noresave{$key} = "$nosave";
 
 $key = q/OPTIONS_AND_ARGUMENTS/;
-$external_latex_labels{$key} = q|A.5.8|; 
+$external_latex_labels{$key} = q|A.5.6|; 
 $noresave{$key} = "$nosave";
 
 $key = q/robot_reset_robot_rewind_robot_add_robot_get_/;
-$external_latex_labels{$key} = q|A.5.11|; 
+$external_latex_labels{$key} = q|A.5.15|; 
 $noresave{$key} = "$nosave";
 
 $key = q/std/;
@@ -774,23 +750,23 @@ $external_latex_labels{$key} = q|4.5.4|;
 $noresave{$key} = "$nosave";
 
 $key = q/configDir/;
-$external_latex_labels{$key} = q|9.1.5|; 
+$external_latex_labels{$key} = q|9.1.4|; 
 $noresave{$key} = "$nosave";
 
 $key = q/Misc_actions/;
-$external_latex_labels{$key} = q|A.5.2|; 
+$external_latex_labels{$key} = q|A.5.1|; 
 $noresave{$key} = "$nosave";
 
 $key = q/Actions_exporting_link_data/;
-$external_latex_labels{$key} = q|A.5.6|; 
+$external_latex_labels{$key} = q|A.5.4|; 
 $noresave{$key} = "$nosave";
 
 $key = q/WaitIntervalHarvesterLockRobotRules/;
-$external_latex_labels{$key} = q|9.1.33|; 
+$external_latex_labels{$key} = q|9.1.29|; 
 $noresave{$key} = "$nosave";
 
 $key = q/INTRODUCTION/;
-$external_latex_labels{$key} = q|A.5.10|; 
+$external_latex_labels{$key} = q|A.5.16|; 
 $noresave{$key} = "$nosave";
 
 $key = q/gory/;
@@ -798,31 +774,23 @@ $external_latex_labels{$key} = q|II|;
 $noresave{$key} = "$nosave";
 
 $key = q/MySQLhandle/;
-$external_latex_labels{$key} = q|9.1.18|; 
-$noresave{$key} = "$nosave";
-
-$key = q/SVMmodel/;
-$external_latex_labels{$key} = q|9.1.25|; 
-$noresave{$key} = "$nosave";
-
-$key = q/analysePlugin/;
-$external_latex_labels{$key} = q|9.1.1|; 
+$external_latex_labels{$key} = q|9.1.16|; 
 $noresave{$key} = "$nosave";
 
 $key = q/SYNOPSIS/;
-$external_latex_labels{$key} = q|A.5.11|; 
+$external_latex_labels{$key} = q|A.5.15|; 
 $noresave{$key} = "$nosave";
 
 $key = q/_get/;
-$external_latex_labels{$key} = q|A.5.11|; 
+$external_latex_labels{$key} = q|A.5.15|; 
 $noresave{$key} = "$nosave";
 
 $key = q/meta_reset_meta_rewind_meta_add_meta_get_/;
-$external_latex_labels{$key} = q|A.5.11|; 
+$external_latex_labels{$key} = q|A.5.15|; 
 $noresave{$key} = "$nosave";
 
 $key = q/new_/;
-$external_latex_labels{$key} = q|A.5.11|; 
+$external_latex_labels{$key} = q|A.5.15|; 
 $noresave{$key} = "$nosave";
 
 $key = q/gettingstarted/;
@@ -834,19 +802,11 @@ $external_latex_labels{$key} = q|9.2.4|;
 $noresave{$key} = "$nosave";
 
 $key = q/LICENSE/;
-$external_latex_labels{$key} = q|A.5.18|; 
+$external_latex_labels{$key} = q|A.5.9|; 
 $noresave{$key} = "$nosave";
 
 $key = q/UserAgentFollowRedirects/;
-$external_latex_labels{$key} = q|9.1.27|; 
-$noresave{$key} = "$nosave";
-
-$key = q/Operator-Email/;
-$external_latex_labels{$key} = q|9.1.19|; 
-$noresave{$key} = "$nosave";
-
-$key = q/domainfocus/;
-$external_latex_labels{$key} = q|2.4.2|; 
+$external_latex_labels{$key} = q|9.1.23|; 
 $noresave{$key} = "$nosave";
 
 $key = q/manpages/;
@@ -857,8 +817,16 @@ $key = q/sqlstruct/;
 $external_latex_labels{$key} = q|A.4|; 
 $noresave{$key} = "$nosave";
 
+$key = q/domainfocus/;
+$external_latex_labels{$key} = q|2.4.2|; 
+$noresave{$key} = "$nosave";
+
+$key = q/Operator-Email/;
+$external_latex_labels{$key} = q|9.1.17|; 
+$noresave{$key} = "$nosave";
+
 $key = q/_add/;
-$external_latex_labels{$key} = q|A.5.11|; 
+$external_latex_labels{$key} = q|A.5.15|; 
 $noresave{$key} = "$nosave";
 
 $key = q/autoclass/;
@@ -866,11 +834,11 @@ $external_latex_labels{$key} = q|4.5|;
 $noresave{$key} = "$nosave";
 
 $key = q/XXX_val_/;
-$external_latex_labels{$key} = q|A.5.11|; 
+$external_latex_labels{$key} = q|A.5.15|; 
 $noresave{$key} = "$nosave";
 
 $key = q/MySQLdatabase/;
-$external_latex_labels{$key} = q|9.1.16|; 
+$external_latex_labels{$key} = q|9.1.15|; 
 $noresave{$key} = "$nosave";
 
 $key = q/sched/;
@@ -878,19 +846,19 @@ $external_latex_labels{$key} = q|4.4|;
 $noresave{$key} = "$nosave";
 
 $key = q/ZebraHost/;
-$external_latex_labels{$key} = q|9.1.41|; 
+$external_latex_labels{$key} = q|9.1.37|; 
 $noresave{$key} = "$nosave";
 
 $key = q/classifyPlugIn/;
-$external_latex_labels{$key} = q|9.1.4|; 
+$external_latex_labels{$key} = q|9.1.3|; 
 $noresave{$key} = "$nosave";
 
 $key = q/SEE_ALSO/;
-$external_latex_labels{$key} = q|A.5.11|; 
+$external_latex_labels{$key} = q|A.5.15|; 
 $noresave{$key} = "$nosave";
 
 $key = q/saveHTML/;
-$external_latex_labels{$key} = q|9.1.22|; 
+$external_latex_labels{$key} = q|9.1.19|; 
 $noresave{$key} = "$nosave";
 
 $key = q/configvars/;
@@ -898,7 +866,7 @@ $external_latex_labels{$key} = q|9|;
 $noresave{$key} = "$nosave";
 
 $key = q/AUTHOR/;
-$external_latex_labels{$key} = q|A.5.20|; 
+$external_latex_labels{$key} = q|A.5.15|; 
 $noresave{$key} = "$nosave";
 
 $key = q/moddep/;
@@ -906,19 +874,19 @@ $external_latex_labels{$key} = q|10|;
 $noresave{$key} = "$nosave";
 
 $key = q/WaitIntervalRrdLockNotFound/;
-$external_latex_labels{$key} = q|9.1.38|; 
+$external_latex_labels{$key} = q|9.1.34|; 
 $noresave{$key} = "$nosave";
 
 $key = q/serveralias/;
 $external_latex_labels{$key} = q|9.2.5|; 
 $noresave{$key} = "$nosave";
 
-$key = q/HarvestRetries/;
-$external_latex_labels{$key} = q|9.1.11|; 
+$key = q/WaitIntervalRrdLockDefault/;
+$external_latex_labels{$key} = q|9.1.33|; 
 $noresave{$key} = "$nosave";
 
-$key = q/WaitIntervalRrdLockDefault/;
-$external_latex_labels{$key} = q|9.1.37|; 
+$key = q/HarvestRetries/;
+$external_latex_labels{$key} = q|9.1.10|; 
 $noresave{$key} = "$nosave";
 
 $key = q/overview/;
@@ -926,39 +894,35 @@ $external_latex_labels{$key} = q|1|;
 $noresave{$key} = "$nosave";
 
 $key = q/UAtimeout/;
-$external_latex_labels{$key} = q|9.1.26|; 
-$noresave{$key} = "$nosave";
-
-$key = q/MySQLfulltext/;
-$external_latex_labels{$key} = q|9.1.17|; 
+$external_latex_labels{$key} = q|9.1.22|; 
 $noresave{$key} = "$nosave";
 
 $key = q/link_reset_link_rewind_link_add_link_get_/;
-$external_latex_labels{$key} = q|A.5.11|; 
+$external_latex_labels{$key} = q|A.5.15|; 
 $noresave{$key} = "$nosave";
 
 $key = q/UserAgentGetIfModifiedSince/;
-$external_latex_labels{$key} = q|9.1.28|; 
+$external_latex_labels{$key} = q|9.1.24|; 
 $noresave{$key} = "$nosave";
 
 $key = q/DESCRIPTION/;
-$external_latex_labels{$key} = q|A.5.20|; 
+$external_latex_labels{$key} = q|A.5.15|; 
 $noresave{$key} = "$nosave";
 
 $key = q/baseConfigDir/;
-$external_latex_labels{$key} = q|9.1.3|; 
+$external_latex_labels{$key} = q|9.1.2|; 
 $noresave{$key} = "$nosave";
 
 $key = q/WaitIntervalHarvesterLockNotModified/;
-$external_latex_labels{$key} = q|9.1.32|; 
+$external_latex_labels{$key} = q|9.1.28|; 
 $noresave{$key} = "$nosave";
 
 $key = q/WaitIntervalHost/;
-$external_latex_labels{$key} = q|9.1.36|; 
+$external_latex_labels{$key} = q|9.1.32|; 
 $noresave{$key} = "$nosave";
 
 $key = q/COPYRIGHT_AND_LICENSE/;
-$external_latex_labels{$key} = q|A.5.20|; 
+$external_latex_labels{$key} = q|A.5.15|; 
 $noresave{$key} = "$nosave";
 
 $key = q/distr/;
@@ -974,7 +938,7 @@ $external_latex_labels{$key} = q|A.2|;
 $noresave{$key} = "$nosave";
 
 $key = q/_reset_/;
-$external_latex_labels{$key} = q|A.5.11|; 
+$external_latex_labels{$key} = q|A.5.15|; 
 $noresave{$key} = "$nosave";
 
 $key = q/termlist/;
@@ -982,7 +946,7 @@ $external_latex_labels{$key} = q|4.5.1|;
 $noresave{$key} = "$nosave";
 
 $key = q/doAnalyse/;
-$external_latex_labels{$key} = q|9.1.6|; 
+$external_latex_labels{$key} = q|9.1.5|; 
 $noresave{$key} = "$nosave";
 
 $key = q/InstTest/;
@@ -990,7 +954,7 @@ $external_latex_labels{$key} = q|A.1|;
 $noresave{$key} = "$nosave";
 
 $key = q/BUGS/;
-$external_latex_labels{$key} = q|A.5.10|; 
+$external_latex_labels{$key} = q|A.5.16|; 
 $noresave{$key} = "$nosave";
 
 $key = q/topicfilter/;
@@ -1005,60 +969,56 @@ $key = q/binext/;
 $external_latex_labels{$key} = q|9.2.2|; 
 $noresave{$key} = "$nosave";
 
-$key = q/EXAMPLES/;
-$external_latex_labels{$key} = q|A.5.7|; 
-$noresave{$key} = "$nosave";
-
 $key = q/Actions_loading_or_recycling_URLs_for_crawling/;
-$external_latex_labels{$key} = q|A.5.2|; 
+$external_latex_labels{$key} = q|A.5.1|; 
 $noresave{$key} = "$nosave";
 
-$key = q/topic_reset_topic_rewind_topic_add_topic_get_/;
-$external_latex_labels{$key} = q|A.5.11|; 
+$key = q/EXAMPLES/;
+$external_latex_labels{$key} = q|A.5.6|; 
 $noresave{$key} = "$nosave";
 
 $key = q/AUTHOR_Anders_Ardo/;
-$external_latex_labels{$key} = q|A.5.18|; 
+$external_latex_labels{$key} = q|A.5.9|; 
+$noresave{$key} = "$nosave";
+
+$key = q/topic_reset_topic_rewind_topic_add_topic_get_/;
+$external_latex_labels{$key} = q|A.5.15|; 
 $noresave{$key} = "$nosave";
 
 $key = q/LogHandle/;
-$external_latex_labels{$key} = q|9.1.13|; 
+$external_latex_labels{$key} = q|9.1.12|; 
 $noresave{$key} = "$nosave";
 
 $key = q/Actions_for_handling_server_aliases/;
-$external_latex_labels{$key} = q|A.5.7|; 
+$external_latex_labels{$key} = q|A.5.6|; 
 $noresave{$key} = "$nosave";
 
 $key = q/WaitIntervalSchedulerGetJcf/;
-$external_latex_labels{$key} = q|9.1.40|; 
+$external_latex_labels{$key} = q|9.1.36|; 
 $noresave{$key} = "$nosave";
 
 $key = q/httpProxy/;
-$external_latex_labels{$key} = q|9.1.12|; 
+$external_latex_labels{$key} = q|9.1.11|; 
 $noresave{$key} = "$nosave";
 
 $key = q/debian/;
 $external_latex_labels{$key} = q|2.1.3|; 
 $noresave{$key} = "$nosave";
 
-$key = q/relTextPlugin/;
-$external_latex_labels{$key} = q|9.1.21|; 
-$noresave{$key} = "$nosave";
-
 $key = q/doCheckRecord/;
-$external_latex_labels{$key} = q|9.1.7|; 
+$external_latex_labels{$key} = q|9.1.6|; 
 $noresave{$key} = "$nosave";
 
 $key = q/WaitIntervalHarvesterLockSuccess/;
-$external_latex_labels{$key} = q|9.1.34|; 
+$external_latex_labels{$key} = q|9.1.30|; 
 $noresave{$key} = "$nosave";
 
 $key = q/_rewind_/;
-$external_latex_labels{$key} = q|A.5.11|; 
+$external_latex_labels{$key} = q|A.5.15|; 
 $noresave{$key} = "$nosave";
 
 $key = q/extractLinksFromText/;
-$external_latex_labels{$key} = q|9.1.9|; 
+$external_latex_labels{$key} = q|9.1.8|; 
 $noresave{$key} = "$nosave";
 
 $key = q/conffiles/;
@@ -1066,7 +1026,7 @@ $external_latex_labels{$key} = q|A.3|;
 $noresave{$key} = "$nosave";
 
 $key = q/Actions_calculating_variants_of_PageRank/;
-$external_latex_labels{$key} = q|A.5.6|; 
+$external_latex_labels{$key} = q|A.5.4|; 
 $noresave{$key} = "$nosave";
 
 $key = q/config/;
